pub struct SimTracer { /* private fields */ }Expand description
Thread-safe event recorder for simulation runs.
Create one per simulation, pass references to components that need to record events, then retrieve the full event log after the run.
Implementations
Sourceimpl SimTracer
impl SimTracer
pub fn new() -> Self
Sourcepub fn record_now(
&self,
node: usize,
face: Option<u32>,
kind: EventKind,
name: impl Into<String>,
detail: Option<String>,
)
pub fn record_now( &self, node: usize, face: Option<u32>, kind: EventKind, name: impl Into<String>, detail: Option<String>, )
Record an event with automatic timestamping.
Sourcepub fn events_for_node(&self, node: usize) -> Vec<SimEvent>
pub fn events_for_node(&self, node: usize) -> Vec<SimEvent>
Filter events by node.
Sourcepub fn events_of_kind(&self, kind: &EventKind) -> Vec<SimEvent>
pub fn events_of_kind(&self, kind: &EventKind) -> Vec<SimEvent>
Filter events by kind.